#!/usr/bin/env node

'use strict';

var path =  require('path');
var async = require('async');
var growl = require('growl');

process.stdin.pipe(process.stdout);

tapGrowl(function (err) {
    if (err) throw err;
    setImmediate(tapGrowl);
});

function tapGrowl (callback) {
    async.waterfall([tapFinished, buildMessage, notify], callback);
}

function tapFinished (callback) {
    var finished = require('tap-finished');
    var notifier = finished(function (results) {
        callback(null, results);
    });
    process.stdin.pipe(notifier);
}

function buildMessage (results, callback) {
    var failed = results.fail.length + results.errors.length;
    var total = results.plan.end;

    var growlOptions = {
        name: 'tap',
        title: failed ? 'Failed' : 'Passed',
        image: image(failed ? 'error' : 'ok')
    };

    var message;
    if (failed) {
        message = failed + ' of ' + total + ' tests failed';
    } else {
        message = total + ' tests passed';
    }

    return callback(null, message, growlOptions);
}

function notify (message, growlOptions, callback) {
    growl(message, growlOptions, callback);
}

function image (name) {
  return path.join(__dirname, './images/' , name + '.png');
}
